determine_next_players_at_hash

Function determine_next_players_at_hash 

fn determine_next_players_at_hash(
    state: &State,
    node: &TempoFullNode,
    hash: B256,
) -> Result<Set<PublicKey>>
Determines the next players depending on the header timestamp identified by digest.

This function should only be used when constructing or verifying a proposal. digest should therefore always refer to the parent parent of the proposal.

If the execution layer does not have a block corresponding to digest available then it cannot propose or verify a block.