pub(crate) fn read_re_dkg_epoch(
node: &TempoFullNode,
digest: Digest,
) -> Result<u64>Expand description
Reads the nextFullDkgCeremony epoch value from one of the validator config contracts.
This is used to determine if the next DKG ceremony should be a full ceremony (new polynomial) instead of a reshare.
This function should only be used when constructing or verifying a proposal.
digest should therefore always refer to the parent parent of the proposal.
If the execution layer does not have a block corresponding to digest
available then it cannot propose or verify a block.